%define majver %(echo %version | cut -d. -f1-2)
Name:          openmpi
Version:       5.0.5
Release:       1mamba
Summary:       A High Performance Message Passing Library
Group:         System/Tools
Vendor:        openmamba
Distribution:  openmamba
Packager:      Silvan Calarco <silvan.calarco@mambasoft.it>
URL:           https://www.open-mpi.org/
Source:        http://www.open-mpi.org/software/ompi/v%{majver}/downloads/openmpi-%{version}.tar.bz2
Patch0:        openmpi-1.8.4-arm-no-unsupported-types.patch
License:       BSD
## AUTOBUILDREQ-BEGIN
BuildRequires: gcc-fortran
BuildRequires: glibc-devel
BuildRequires: libevent-devel
BuildRequires: libgcc
BuildRequires: libhwloc-devel
BuildRequires: libopenpmix-devel
%ifnarch arm aarch64
BuildRequires: libquadmath-devel
%endif
## AUTOBUILDREQ-END
BuildRequires: libprrte-devel
BuildRequires: javapackages
Requires:      libmpi = %{?epoch:%epoch:}%{version}-%{release}

%description
The Open MPI Project is an open source MPI-2 implementation that is developed and maintained by a consortium of academic, research, and industry partners. Open MPI is therefore able to combine the expertise, technologies, and resources from all across the High Performance Computing community in order to build the best MPI library available. Open MPI offers advantages for system and software vendors, application developers and computer science researchers. 

%package devel
Summary:       Devel package for %{name}
Group:         Development/Libraries
Requires:      %{name} = %{?epoch:%epoch:}%{version}-%{release}
Requires:      libmpi-devel = %{?epoch:%epoch:}%{version}-%{release}
Requires:      libprrte-devel

%description devel
The Open MPI Project is an open source MPI-2 implementation that is developed and maintained by a consortium of academic, research, and industry partners. Open MPI is therefore able to combine the expertise, technologies, and resources from all across the High Performance Computing community in order to build the best MPI library available. Open MPI offers advantages for system and software vendors, application developers and computer science researchers. 
This package contains mpi compilers.

%package -n libmpi
Summary:       A High Performance Message Passing Library
Group:         System/Libraries

%description -n libmpi
The Open MPI Project is an open source MPI-2 implementation that is developed and maintained by a consortium of academic, research, and industry partners. Open MPI is therefore able to combine the expertise, technologies, and resources from all across the High Performance Computing community in order to build the best MPI library available. Open MPI offers advantages for system and software vendors, application developers and computer science researchers. 
This package contains the project shared libraries.

%package -n libmpi-devel
Summary:       Devel package for %{name}
Group:         Development/Libraries
Requires:      libmpi = %{?epoch:%epoch:}%{version}-%{release}

%description -n libmpi-devel
The Open MPI Project is an open source MPI-2 implementation that is developed and maintained by a consortium of academic, research, and industry partners. Open MPI is therefore able to combine the expertise, technologies, and resources from all across the High Performance Computing community in order to build the best MPI library available. Open MPI offers advantages for system and software vendors, application developers and computer science researchers. 
This package contains static libraries and header files needed for development.

%debug_package

%prep
%setup -q
#-D -T
#:<< _EOF
%ifarch arm
sed -i "s|armv5\*linux|arm*linux|" configure || exit 1
%endif
#%patch0 -p1

%build
#:<< _EOF
%configure \
   --sysconfdir=%{_sysconfdir}/openmpi \
   --datarootdir=%{_datadir}/openmpi \
   --datadir=%{_datadir}/openmpi \
   --with-prrte=external \
   --with-libevent=external \
   --with-pmix=external

%make

%install
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"
%makeinstall

## not installed as of 1.4.3 but symlink otfdecompress pointing to it it is
#install -D -m0755 ./ompi/contrib/vt/vt/extlib/otf/tools/otfcompress/otfcompress %{buildroot}%{_bindir}/otfcompress

# %{_bindir}/otfinfo: conflicts with texlive
#mv %{buildroot}%{_bindir}/otfinfo %{buildroot}%{_bindir}/otfinfompi

%clean
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"

%files
%defattr(-,root,root)
%dir %{_sysconfdir}/openmpi
%config(noreplace) %{_sysconfdir}/openmpi/openmpi-mca-params.conf
%config(noreplace) %{_sysconfdir}/openmpi/openmpi-totalview.tcl
%{_bindir}/mpiexec
%{_bindir}/mpirun
%{_bindir}/ompi_info
%{_bindir}/oshrun
%dir %{_datadir}/openmpi
%{_datadir}/openmpi/*
#%{_mandir}/man1/mpirun.1*
%{_mandir}/man1/ompi-*.1*
%{_mandir}/man1/ompi_info.1*
%{_mandir}/man1/opal_wrapper.1*
%{_mandir}/man1/mpi*.1*
%doc AUTHORS LICENSE

%files devel
%defattr(-,root,root)
%{_bindir}/mpiCC
%{_bindir}/mpic++
%{_bindir}/mpicc
%{_bindir}/mpicxx
%{_bindir}/mpif77
%{_bindir}/mpif90
%{_bindir}/mpifort
%{_bindir}/opal_wrapper
#%{_mandir}/man5/openpmix.5*
%{_mandir}/man7/Open-MPI.7*

%files -n libmpi
%defattr(-,root,root)
%{_libdir}/mpi*.mod
%{_libdir}/pmpi_f08_interfaces.mod
%{_libdir}/libmpi*.so.*
%{_libdir}/libopen*.so.*
%{_libdir}/openmpi/libompi_*.so

%files -n libmpi-devel
%defattr(-,root,root)
%{_includedir}/*.h
%dir %{_includedir}/openmpi
%{_includedir}/openmpi/*
%{_libdir}/libmpi*.so
%{_libdir}/libopen-pal.so
%{_libdir}/pkgconfig/ompi-c.pc
%{_libdir}/pkgconfig/ompi-cxx.pc
%{_libdir}/pkgconfig/ompi-f77.pc
%{_libdir}/pkgconfig/ompi-f90.pc
%{_libdir}/pkgconfig/ompi-fort.pc
%{_libdir}/pkgconfig/ompi.pc
%{_mandir}/man3/*.3*
#%doc NEWS README

%changelog
* Tue Jul 23 2024 Automatic Build System <autodist@openmamba.org> 5.0.5-1mamba
- automatic version update by autodist

* Sat Jul 20 2024 Automatic Build System <autodist@openmamba.org> 5.0.4-1mamba
- automatic version update by autodist

* Fri Apr 12 2024 Automatic Build System <autodist@openmamba.org> 5.0.3-1mamba
- automatic version update by autodist

* Thu Feb 08 2024 Automatic Build System <autodist@openmamba.org> 5.0.2-1mamba
- automatic version update by autodist

* Fri Dec 22 2023 Automatic Build System <autodist@mambasoft.it> 5.0.1-1mamba
- automatic version update by autodist

* Thu Nov 02 2023 Silvan Calarco <silvan.calarco@mambasoft.it> 5.0.0-3mamba
- rebuilt with openpmix

* Thu Nov 02 2023 Silvan Calarco <silvan.calarco@mambasoft.it> 5.0.0-2mamba
- rebuilt with system prrte

* Sat Oct 28 2023 Automatic Build System <autodist@mambasoft.it> 5.0.0-1mamba
- automatic version update by autodist

* Mon Sep 04 2023 Silvan Calarco <silvan.calarco@mambasoft.it> 4.1.5-1mamba
- update to 4.1.5

* Sat May 28 2022 Automatic Build System <autodist@mambasoft.it> 4.1.4-1mamba
- automatic version update by autodist

* Sat Apr 02 2022 Automatic Build System <autodist@mambasoft.it> 4.1.3-1mamba
- automatic version update by autodist

* Thu Nov 25 2021 Automatic Build System <autodist@mambasoft.it> 4.1.2-1mamba
- automatic version update by autodist

* Wed Apr 28 2021 Automatic Build System <autodist@mambasoft.it> 4.1.1-1mamba
- automatic version update by autodist

* Sat Feb 20 2021 Automatic Build System <autodist@mambasoft.it> 4.1.0-1mamba
- automatic version update by autodist

* Sat Sep 26 2020 Automatic Build System <autodist@mambasoft.it> 4.0.5-1mamba
- automatic version update by autodist

* Sat Jun 20 2020 Automatic Build System <autodist@mambasoft.it> 4.0.4-1mamba
- automatic version update by autodist

* Sat Apr 25 2020 Silvan Calarco <silvan.calarco@mambasoft.it> 4.0.3-2mamba
- libmpi: move multilib conflicting files to openmpi package; add debug package

* Sun Mar 08 2020 Automatic Build System <autodist@mambasoft.it> 4.0.3-1mamba
- automatic version update by autodist

* Fri Oct 11 2019 Automatic Build System <autodist@mambasoft.it> 4.0.2-1mamba
- automatic version update by autodist

* Mon Apr 01 2019 Automatic Build System <autodist@mambasoft.it> 4.0.1-1mamba
- automatic version update by autodist

* Mon Nov 12 2018 Automatic Build System <autodist@mambasoft.it> 3.1.3-1mamba
- automatic version update by autodist

* Tue Sep 18 2018 Automatic Build System <autodist@mambasoft.it> 3.1.2-1mamba
- automatic version update by autodist

* Mon Aug 20 2018 Automatic Build System <autodist@mambasoft.it> 3.1.1-1mamba
- automatic version update by autodist

* Tue Jun 19 2018 Automatic Build System <autodist@mambasoft.it> 3.1.0-1mamba
- automatic version update by autodist

* Mon Apr 16 2018 Automatic Build System <autodist@mambasoft.it> 3.0.1-1mamba
- automatic version update by autodist

* Sat Nov 18 2017 Automatic Build System <autodist@mambasoft.it> 1.10.7-1mamba
- automatic update by autodist

* Fri Mar 03 2017 Automatic Build System <autodist@mambasoft.it> 1.10.6-1mamba
- automatic version update by autodist

* Fri Dec 23 2016 Automatic Build System <autodist@mambasoft.it> 1.10.5-1mamba
- automatic version update by autodist

* Tue Sep 06 2016 Automatic Build System <autodist@mambasoft.it> 1.10.4-1mamba
- automatic version update by autodist

* Thu Jun 23 2016 Automatic Build System <autodist@mambasoft.it> 1.10.3-1mamba
- automatic version update by autodist

* Sun Jan 24 2016 Automatic Build System <autodist@mambasoft.it> 1.10.2-1mamba
- automatic version update by autodist

* Tue Nov 24 2015 Automatic Build System <autodist@mambasoft.it> 1.10.1-1mamba
- automatic version update by autodist

* Sun Sep 13 2015 Automatic Build System <autodist@mambasoft.it> 1.10.0-1mamba
- automatic version update by autodist

* Fri Aug 07 2015 Automatic Build System <autodist@mambasoft.it> 1.8.8-1mamba
- automatic version update by autodist

* Sat Jul 18 2015 Automatic Build System <autodist@mambasoft.it> 1.8.7-1mamba
- automatic version update by autodist

* Tue Jun 23 2015 Automatic Build System <autodist@mambasoft.it> 1.8.6-1mamba
- automatic version update by autodist

* Sun May 24 2015 Automatic Build System <autodist@mambasoft.it> 1.8.5-1mamba
- automatic version update by autodist

* Sun Dec 28 2014 Automatic Build System <autodist@mambasoft.it> 1.8.4-1mamba
- automatic version update by autodist

* Tue Sep 30 2014 Automatic Build System <autodist@mambasoft.it> 1.8.3-1mamba
- automatic version update by autodist

* Fri Sep 05 2014 Automatic Build System <autodist@mambasoft.it> 1.8.2-1mamba
- automatic version update by autodist

* Fri Apr 25 2014 Automatic Build System <autodist@mambasoft.it> 1.8.1-1mamba
- automatic version update by autodist

* Sun Apr 13 2014 Automatic Build System <autodist@mambasoft.it> 1.8-1mamba
- automatic version update by autodist

* Fri Nov 15 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 1.6.5-4mamba
- rebuild after previous release was built with buggy rpm

* Thu Nov 14 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 1.6.5-3mamba
- move compilers to openmpi-devel new subpackage

* Thu Jul 11 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 1.6.5-2mamba
- rename %{_bindir}/otfinfo to %{_bindir}/otfinfompi to resolve a conflict with texlive

* Sun Jun 30 2013 Automatic Build System <autodist@mambasoft.it> 1.6.5-1mamba
- automatic version update by autodist

* Sat Feb 23 2013 Automatic Build System <autodist@mambasoft.it> 1.6.4-1mamba
- automatic version update by autodist

* Wed Nov 07 2012 Automatic Build System <autodist@mambasoft.it> 1.6.3-1mamba
- automatic version update by autodist

* Mon Oct 08 2012 Automatic Build System <autodist@mambasoft.it> 1.6.2-1mamba
- automatic version update by autodist

* Tue Aug 07 2012 Automatic Build System <autodist@mambasoft.it> 1.6-1mamba
- automatic version update by autodist

* Fri Oct 28 2011 Automatic Build System <autodist@mambasoft.it> 1.4.4-1mamba
- automatic version update by autodist

* Wed Dec 01 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 1.4.3-1mamba
- update to 1.4.3

* Fri Jun 25 2010 Automatic Build System <autodist@mambasoft.it> 1.3.4-1mamba
- automatic update by autodist

* Sat Jun 06 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 1.3.2-1mamba
- package created by autospec
